==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/lyrics/translations/lyrics_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Voir les paroles</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="30"/>
        <source>Lyrics Plugin</source>
        <translation>Greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>À propos du greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Greffon de paroles pour Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Ce greffon récupère les paroles depuis LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="54"/>
        <source>Based on Ultimate Lyrics script by Vladimir Brkic &lt;vladimir_brkic@yahoo.com&gt;</source>
        <translation>Basé sur le script Ultimate Lyrics par Vladimir Brkic
&lt;vladimir_brkic@yahoo.com&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Provider:</source>
        <translation>Fournisseur:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="122"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="139"/>
        <source>Track:</source>
        <translation>Piste:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="146"/>
        <source>Artist:</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="161"/>
        <source>Year:</source>
        <translation>Année:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="115"/>
        <source>Title:</source>
        <translation>Titre :</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="113"/>
        <source>&lt;h2&gt;%1 - %2&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 - %2&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Not found</source>
        <translation>Non trouvé</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="134"/>
        <source>Error: %1 - %2</source>
        <translation>Erreur: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="147"/>
        <source>Receiving</source>
        <translation>Réception</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="202"/>
        <source>cache</source>
        <translation>cache</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Lyrics Plugin Settings</source>
        <translation>Configuration du greffon Paroles</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Lyrics providers:</source>
        <translation>Fournisseurs de Paroles:</translation>
    </message>
</context>
<context>
    <name>UltimateLyricsParser</name>
    <message>
        <location filename="../ultimatelyricsparser.cpp" line="118"/>
        <source>%1 (line: %2)</source>
        <translation>%1 (ligne: %2)</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/General/lyrics/translations/lyrics_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="33"/>
        <source>View Lyrics</source>
        <translation>Voir les paroles</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="34"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>À propos du greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Greffon de paroles pour Qmmp</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Ce greffon récupère les paroles depuis LyricWiki</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Greffon de paroles</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Titre :</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Pas de connexion</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>Fait</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>Non trouvé</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Réception</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Paroles : %1 - %2</translation>
    </message>
</context>
</TS>
